package com.mortals.xhx.base.system.menu.service;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.ICRUDService;
import com.mortals.framework.service.IUser;
import com.mortals.xhx.base.system.menu.model.MenuEntity;
import com.mortals.xhx.base.system.menu.model.MenuTreeSelect;

import java.util.List;
import java.util.Set;

/**
 * MenuService
 * <p>
 * 菜单信息 service接口
 *
 * @author zxfei
 * @date 2023-04-10
 */
public interface MenuService extends ICRUDService<MenuEntity, Long> {

    /**
     * 获取所有可用菜单
     *
     * @return
     * @throws AppException
     */
    public List<MenuEntity> findAllEnable() throws AppException;

    /**
     * 查询有权限的菜单
     *
     * @param user 当前用户
     * @param urls 有权限的访问地址集合
     * @return
     * @throws AppException
     */
    public List<MenuEntity> findTreeMenu(IUser user, Set<String> urls) throws AppException;

    /**
     * 查看所有菜单
     *
     * @return
     * @throws AppException
     */
    public List<MenuEntity> findTreeMenu() throws AppException;


    /**
     * 更新排列顺序
     *
     * @param id
     * @param type
     */
    void upOrDown(Long id, Integer type);


    /**
     * 是否存在菜单信息节点
     *
     * @param menuId 菜单信息ID
     * @return 结果
     */
    boolean hasChildByMenuId(Long menuId);


    /**
     * 查询菜单信息数据
     *
     * @param menu 菜单信息
     * @return 菜单信息集合
     */
    List<MenuEntity> selectMenuList(MenuEntity menu);


    /**
     * 构建前端所需要下拉树结构
     *
     * @param menuList 菜单信息列表
     * @return 下拉树结构列表
     */
    List<MenuTreeSelect> buildMenuTreeSelect(List<MenuEntity> menuList);

    /**
     * 根据父id查询子节点
     *
     * @param parentId
     * @param context
     * @return
     */
    List<MenuTreeSelect> getListByParentId(Long parentId, Context context);

    Set<Long> getPathSetById(Long id, Context context);
}