package com.mortals.xhx.module.check.web;
import cn.hutool.core.date.DateUtil;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.common.code.*;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.dept.service.DeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.check.model.CheckOtherRecordEntity;
import com.mortals.xhx.module.check.service.CheckOtherRecordService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 其它绩效核查信息
*
* @author zxfei
* @date 2023-07-11
*/
@RestController
@RequestMapping("check/other/record")
public class CheckOtherRecordController extends BaseCRUDJsonBodyMappingController<CheckOtherRecordService,CheckOtherRecordEntity,Long> {

    @Autowired
    private ParamService paramService;

    @Autowired
    private UserService userService;
    @Autowired
    private DeptService deptService;
    public CheckOtherRecordController(){
        super.setModuleDesc( "其它绩效核查信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "irregularOtherType", paramService.getParamBySecondOrganize("CheckOtherRecord","irregularOtherType"));
        this.addDict(model, "checkStatus", CheckStatusEnum.getEnumMap());
        this.addDict(model, "subMethod", SubMethodEnum.getEnumMap());
        this.addDict(model, "subAddType", SubAddTypeEnum.getEnumMap());
        this.addDict(model, "checkType", CheckTypeEnum.getEnumMap());
        this.addDict(model, "checkResult", CheckResultEnum.getEnumMap());
        this.addDict(model, "checkResultAdd", CheckResultAddEnum.getEnumMap());
        this.addDict(model, "checkResultSub", CheckResultSubEnum.getEnumMap());

        this.addDict(model, "deptId", deptService.find(new DeptQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getDeptName())));

        Map<String, String> collect = userService.find(new UserQuery(), getContext()).stream()
                .collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getRealName(), (o, n) -> n));

        this.addDict(model, "createUserId", collect);
    }

    @Override
    protected void doListBefore(CheckOtherRecordEntity query, Map<String, Object> model, Context context) throws AppException {
        super.doListBefore(query, model, context);
        if (ObjectUtils.isEmpty(query.getOrderColList())) {
            query.setOrderColList(Arrays.asList(new OrderCol("createTime", OrderCol.DESCENDING)));
        } else {
            query.getOrderColList().add(new OrderCol("createTime", OrderCol.DESCENDING));
        }

        if(!ObjectUtils.isEmpty(query.getCreateTime())){
            query.setCreateTimeStart(DateUtil.formatDate(query.getCreateTime()));
            query.setCreateTimeEnd(DateUtil.formatDate(query.getCreateTime()));
        }
    }

    /**
     * 审核
     * @param entity
     * @return
     */
    @PostMapping({"examine"})
    public String examine(@RequestBody CheckOtherRecordEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        int code = 1;
        String busiDesc = "考勤绩效核查审核";
        try {
            this.service.examine(entity, context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var9) {
            this.doException(this.request, busiDesc, model, var9);
            model.put("entity", entity);
            this.init(model, context);
            code = this.saveException(entity, model, context, var9);
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }
}