package com.mortals.xhx.module.staff.web;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.dept.model.DeptTreeSelect;
import com.mortals.xhx.module.dept.service.DeptService;
import com.mortals.xhx.module.job.model.JobEntity;
import com.mortals.xhx.module.job.model.JobQuery;
import com.mortals.xhx.module.job.service.JobService;
import com.mortals.xhx.module.staff.model.StaffEntity;
import com.mortals.xhx.module.staff.model.vo.HolidayListVo;
import com.mortals.xhx.module.staff.model.vo.StaffInfoVo;
import com.mortals.xhx.module.staff.service.StaffService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
*
* 员工基本信息
*
* @author zxfei
* @date 2023-04-07
*/
@RestController
@RequestMapping("staff")
public class StaffController extends BaseCRUDJsonBodyMappingController<StaffService,StaffEntity,Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private JobService jobService;
    @Autowired
    private DeptService deptService;

    public StaffController(){
        super.setModuleDesc( "员工基本信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "gender", paramService.getParamBySecondOrganize("Staff","gender"));
        this.addDict(model, "politicalstatus", paramService.getParamBySecondOrganize("Staff","politicalstatus"));
        this.addDict(model, "staffType", paramService.getParamBySecondOrganize("Staff","staffType"));
        this.addDict(model, "status", paramService.getParamBySecondOrganize("Staff","status"));
        this.addDict(model, "positionId", jobService.queryPositionName(new JobQuery()).stream().collect(Collectors.toMap(x->x.getId().toString(),y->y.getJobName(),(o,n)->n)));
        List<DeptEntity> list = deptService.find(new DeptQuery());
        List<DeptTreeSelect> treeSelects = deptService.buildDeptTreeSelect(list);
        this.addDict(model,"deptPerson",treeSelects);

        this.addDict(model, "deptId", deptService.find(new DeptQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getDeptName())));


        super.init(model, context);
    }


    @Override
    protected int doListAfter(StaffEntity query, Map<String, Object> model, Context context) throws AppException {
        //todo 员工信息统计--员工关系统计
        StaffInfoVo staffInfoVo = this.service.queryAll();
        staffInfoVo.setRefreshDate(new Date());
        model.put("staff", staffInfoVo);
        return super.doListAfter(query, model, context);
    }


    @Override
    protected int infoAfter(Long id, Map<String, Object> model, StaffEntity entity, Context context) throws AppException {
        //todo 员工统计信息
        List<HolidayListVo> holidayListVos = new ArrayList<>();
        HolidayListVo vo =new HolidayListVo();
        StaffEntity staffEntity = this.service.get(id);
        vo.setWorkName(staffEntity.getName());
        vo.setWorkStatus(String.valueOf(staffEntity.getStatus()));
        vo.setWorkDept(staffEntity.getDeptName());
        vo.setWorkLimit("1003");
        vo.setWorkBeginDay(staffEntity.getEntryDate());
        vo.setWorkFormalDay(staffEntity.getRegularDate());
        vo.setAttendanceCount("22");
        vo.setLeaveCount("2");
        vo.setLateCount("1");
        vo.setMinerCount("1");
        vo.setLackCardCount("0");
        vo.setWorkOverDay("2");
        vo.setCompensatoryDay("10");
        vo.setMarriageHoliday("10");
        vo.setWinterHoliday("10");
        vo.setPaternityLeaveDay("10");
        holidayListVos.add(vo);
        entity.setHolidayLists(holidayListVos);
       // StaffEntity cache = this.service.getCache(entity.getWorkNum());
        return super.infoAfter(id, model, entity, context);
    }

}

